require "sfdc_se/version"
require "rubygems"
require "selenium-webdriver"
require 'restforce'
require 'rforce'
require "sfdc_se/pages/page_setup"
require "sfdc_se/pages/page_deliverability"
require	"sfdc_se/pages/page_homepagelayouts"
require "sfdc_se/pages/page_personalinformation"
require "sfdc_se/pages/page_profiles"
require "sfdc_se/pages/page_sharingsettings"
require "sfdc_se/pages/page_emailalerts"
require "sfdc_se/pages/page_fieldupdates"
require "sfdc_se/pages/page_passwordsecuritysetting"
require "sfdc_se/pages/page_translate"
require "sfdc_se/pages/page_renametabslabels"
require "sfdc_se/general/general"

module SfdcSe
  class Driver
  	
  	# -----------------------------
  	# initialize
  	# => opts:
  	# =>  	:browserName = firefox, Chrome, etc (currently only providen for FF, default value)
  	# =>  	:implicitWaitSec = the time out for implicit waits in secs; 30 sec default value
    # =>    :explicitWaitSec = the time out for explicit waits in secs; 30 sec default value
  	#
  	def initialize(opts = {})
  		@browser=opts[:browserName] || 'firefox'.to_sym
  		if @browser.is_a? String
  			@browser.to_sym
  		end

  		@implicitWait=opts[:implicitWaitSec] || 30
  		if !@implicitWait.is_a?(Numeric)
  			@implicitWait.to_i
  		end

      @explicitWait=opts[:explicitWaitSec] || 30
      if !@explicitWait.is_a?(Numeric)
        @explicitWait.to_i
      end

  		@driver = Selenium::WebDriver.for @browser
  		@driver.manage.window.maximize
		  @driver.manage.timeouts.implicit_wait = @implicitWait
		  setExplicitWait @explicitWait
		  return @driver
  	end

  	# -----------------------------
  	# setExplicitWait
  	# => used to set the explicit waits in secs
  	# => secs = timeout in secs
  	#
  	def setExplicitWait(secs)
  		@explicitWait=secs || 30
  		if !@explicitWait.is_a?(Numeric)
  			@explicitWait.to_i
  		end
  		@wait=Selenium::WebDriver::Wait.new(:timeout => @explicitWait)
  		return @wait
  	end

  	# -----------------------------
  	# navigate_to
  	# => url = path to which the browser will navigate to
  	#
  	def navigate_to(url)
  		@driver.navigate.to url
  	end

    # -----------------------------
    # click_Continue_verifyUsername
    # => url = path to which the browser will navigate to
    #
    def click_Continue_verifyUsername
      if @driver.find_elements(:id => 'thePage:inputForm:continue').size > 0
        @driver.find_element(:id => 'thePage:inputForm:continue').click
      end
    end

  	# -----------------------------
  	# navigate_to_setup
  	# => Navigates to the Setup section/page of SFDC
  	#
  	def navigate_to_setup
  		@driver.find_element(:id => 'userNavLabel').click
		  @driver.find_element(:link_text => 'Setup').click
	  end

  	# -----------------------------
  	# take screenshot
  	def save_screenshot(filename)
  		@driver.save_screenshot(filename)
  	end

  	# -----------------------------
  	# close
  	def close
  		@driver.quit
  	end

    # -----------------------------
    # Header Logo Verification
    def verify_HeaderLogoExists
      if @driver.find_elements(:id => "phHeaderLogoImage").size > 0
        return true
      else
        return false
      end
    end

    # -----------------------------
    # Translation Abbreviation Converter
    def convert_LanguageAbbreviation(sLanguageAbbrevation)
      case sLanguageAbbrevation
      when "zh_CN"
        return "Chinese (Simplified)"
      when "zh_TW"
        return "Chinese (Traditional)"
      when "da"
        return "Danish"
      when "nl_NL"
        return "Dutch"
      when "en_US"
        return "English"
      when "fi"
        return "Finnish"
      when "fr"
        return "French"
      when "de"
        return "German"
      when "it"
        return "Italian"
      when "ja"
        return "Japanese"
      when "ko"
        return "Korean"
      when "no"
        return "Norwegian"
      when "pt_BR"
        return "Portuguese (Brazilian)"
      when "ru"
        return "Russian"
      when "es"
        return "Spanish"
      when "es_MX"
        return "Spanish (Mexican)"
      when "sv"
        return "Swedish"
      when "th"
        return "Thai"
      when "ar"
        return "Arabic"
      when "bg"
        return "Bulgarian"
      when "hr"
        return "Croatian"
      when "cs"
        return "Czech"
      when "en_GB"
        return "English (UK)"
      when "el"
        return "Greek"
      when "iw"
        return "Hebrew"
      when "hu"
        return "Hungarian"
      when "in"
        return "Indonesian"
      when "pl"
        return "Polish"
      when "pt_PT"
        return "Portuguese (European)"
      when "ro"
        return "Romanian"
      when "sk"
        return "Slovak"
      when "sl"
        return "Slovene"
      when "tr"
        return "Turkish"
      when "uk"
        return "Ukrainian"
      when "vi"
        return "Vietnamese"
      end
    end
    # -----------------------------

  end
end
