# ----------------------------------------------
# - Page: Sharing Settings
# ----------------------------------------------

module SfdcSe
  class Driver
  	
  	# -----------------------------
    # get_SharingSettingOptions
    # => returns all the elements for the Sharing Settings dropdown
  	def get_SharingSettingOptions
  		return @driver.find_elements(:xpath => "//select[@id='st']/option")
  	end
  	# -----------------------------

  	# -----------------------------
    # get_SharingSettingAccessTable
    # => returns all the elements for the Sharing Settings Access Table
  	def get_SharingSettingAccessTable
  		return @driver.find_elements(:xpath => "//table[@class='list']/tbody/tr")
  	end
  	# -----------------------------

    # -----------------------------
    # get_SharingSettingAccessTable_Edit
    # => returns all the elements for the Sharing Settings Access Table
    def get_SharingSettingAccessTable_Edit
      return @driver.find_elements(:xpath => "//table[@class='detailList']/tbody/tr")
    end
    # -----------------------------
    

    # -----------------------------
    # click_Btn_SharingSettingsAccess_Edit
    # => clicks the Edit button on the Sharing Setting Access Page
    def click_Btn_SharingSettingsAccess_Edit
      @driver.find_element(:xpath => "//input[@title = 'Edit' and @class='btn']").click
    end
    # -----------------------------


    # -----------------------------
    # click_Btn_SharingSettingsAccess_Save
    # => clicks the Save button on the Sharing Setting Access Page
    def click_Btn_SharingSettingsAccess_Save
      sMsg=""
      @driver.find_element(:xpath => "//input[@title = 'Save' and @class='btn']").click

      a= @driver.switch_to.alert rescue "Exception happened"
      if !(a == "Exception happened")
        if a.text.include? "All sharing rules will be recalculated based on the new defaults"
          sMsg= "Accepting Alert: #{a.text}"
          a.accept
        else
          sMsg= "NOT Accepting Alert: #{a.text}"
          a.dismiss
        end
      end
      return sMsg
    end
    # -----------------------------


    # -----------------------------
    # click_Btn_SharingSettingsAccess_SavePrompt_OK
    # => clicks the Save button on the Sharing Setting Access Page
    def click_Btn_SharingSettingsAccess_SavePrompt_OK
      cWindowHandle=@driver.window_handle
      puts "Current Window Handle: #{cWindowHandle}"
      puts "Open Windoes of browser: #{@driver.window_handles}"
      @driver.window_handles.each do |win|
        if !(win == cWindowHandle)
          @driver.switch_to(win)
          @driver.action.send_keys("\n").perform
          @driver.switch_to(cWindowHandle)
        end
      end
      
    end
    # -----------------------------
    


  	# -----------------------------
    # set_SharingSetting_View
    # => sViewName = string value of the Sharing Setting option to select
    # => Return = true or false
    # =>    true  = setting of view were successful
    # =>    false = setting of view had an error
    #
  	def set_SharingSetting_View(sViewName)
  		blnViewSet=false
  		begin
  			get_SharingSettingOptions.each do |option|
  				if option.text == sViewName
  					option.click unless option.selected?
  					blnViewSet=true
  					return blnViewSet
  				end
  			end
  		rescue
  			puts $!
	    	puts $@
  		end
  		return blnViewSet
  	end
  	# -----------------------------

  	# -----------------------------
  	# => sObjName = string value of the sharing setting object to return
  	# => Return = Hash of column values for indicated object name
  	#
  	def get_SharingSettingsAccess(sObjName)
  		$accessHeaders=[]
  		response=Hash.new

  		get_SharingSettingAccessTable.each_with_index do |row, index|
  			if index == 0
  				# - Get headers
  				row.find_elements(:xpath => "./th").each do |h|
  					$accessHeaders.push(h.text)
  				end
  			else
  				# - Get Values for matching Object Name
  				if row.find_element(:xpath => "./th").text == sObjName
  					response[$accessHeaders[1]]=row.find_element(:xpath => "./td[1]").text
  					response[$accessHeaders[2]]=row.find_element(:xpath => "./td[2]").text
  					response[$accessHeaders[3]]=row.find_element(:xpath => "./td/img").attribute("title") unless row.find_elements(:xpath => "./td[3]//*").size == 0
  					break
  				end
  			end
  		end

  		return response
  	end
  	# -----------------------------

    # -----------------------------
    # => sObjName = string value of the sharing setting object to return
    # => hOjbValues = Hash of the values to verify for the sObjName
    # => Return = true/false
    #     - True if values match
    #     - False if values do not match
    #    
    def verify_SharingSettingsAccess(sObjName, hObjValues)
        @driver.manage.timeouts.implicit_wait = 0
        blnVerify=true
        $accessHeaders=[]

        # hObjValues[sObjName].each do |k,v|
        #   puts "\t\t#{k}: #{v}"
        # end
        
        get_SharingSettingAccessTable.each_with_index do |row, index|
          if index == 0
            # - Get headers
            row.find_elements(:xpath => "./th").each do |h|
              $accessHeaders.push(h.text)
            end
          else
            # Check values against hObjValues
            if row.find_element(:xpath => "./th").text == sObjName
              if !(hObjValues[sObjName][$accessHeaders[1]]==row.find_element(:xpath => "./td[1]").text)
                puts "#{$accessHeaders[1]}: #{hObjValues[sObjName][$accessHeaders[1]]} | #{row.find_element(:xpath => "./td[1]").text}"
                blnVerify=false
              end

              if !(hObjValues[sObjName][$accessHeaders[2]]==row.find_element(:xpath => "./td[2]").text)
                puts "#{$accessHeaders[2]}: #{hObjValues[sObjName][$accessHeaders[2]]} | #{row.find_element(:xpath => "./td[2]").text}"
                blnVerify=false
              end

              if row.find_elements(:xpath => "./td[3]//*").size > 0
                if !(hObjValues[sObjName][$accessHeaders[3]]==row.find_element(:xpath => "./td/img").attribute("title"))
                  puts "#{$accessHeaders[3]}: #{hObjValues[sObjName][$accessHeaders[3]]} | #{row.find_element(:xpath => "./td/img").attribute("title")}"
                  blnVerify=false
                end
              end

              break
            end
          end
        end

        @driver.manage.timeouts.implicit_wait = @implicitWait
        return blnVerify
    end
    # -----------------------------


    # -----------------------------
    # => sObjName = string value of the sharing setting object to return
    # => hOjbValues = Hash of the values to verify for the sObjName
    # => Return = true/false
    #     - True if values match
    #     - False if values do not match
    #    
    def set_SharingSettingAccess_Edit(sObjName, hObjValues)
      @driver.manage.timeouts.implicit_wait = 0
      blnUpdateSuccessful=false
      $accessHeaders=[]

      # - Perform Update Actions
      get_SharingSettingAccessTable_Edit.each_with_index do |row, index|
        if index == 0
          # - Get headers
          row.find_elements(:xpath => "./th").each do |h|
            $accessHeaders.push(h.text)
          end
        else
            # - Perform Updates to columns
            if row.find_element(:xpath => "./td[1]").text == sObjName
              # - Column: Default Internal Access (dropdown selection)
              if row.find_elements(:xpath => "./td[2]//*").size > 0
                if !(hObjValues[sObjName][$accessHeaders[1]]==row.find_element(:xpath => "./td[2]/select/option[@selected='selected']").text)
                  row.find_elements(:xpath => "./td[2]/select/option").each do |option|
                    if option.text == hObjValues[sObjName][$accessHeaders[1]]
                      option.click unless option.selected?
                      # puts "-- ** Set Default Internal Access **"
                      blnUpdateSuccessful=true
                    end
                  end
                end
              end

              # - Column: Default External Access (dropdown selection)
              if row.find_elements(:xpath => "./td[3]//*").size > 0
                if !(hObjValues[sObjName][$accessHeaders[2]]==row.find_element(:xpath => "./td[3]/select/option[@selected='selected']").text)
                  row.find_elements(:xpath => "./td[3]/select/option").each do |option|
                    if option.text == hObjValues[sObjName][$accessHeaders[1]]
                      option.click unless option.selected?
                      # puts "-- ** Set Default External Access **"
                      blnUpdateSuccessful=true
                    end
                  end
                end
              end

              # - Grant Access Using Hierarchies (checkbox)
              if row.find_element(:xpath => "./td[4]/input").attribute("disabled").nil?
                # puts "Checkbox Not Disabled"
                if (hObjValues[sObjName][$accessHeaders[3]]) == "Checked"
                  row.find_element(:xpath => "./td[4]/input[@type='checkbox']").click unless !row.find_element(:xpath => "./td[4]/input").attribute("checked").nil?
                  blnUpdateSuccessful=true
                else
                  row.find_element(:xpath => "./td[4]/input[@type='checkbox']").click unless row.find_element(:xpath => "./td[4]/input").attribute("checked").nil?
                  blnUpdateSuccessful=true
                end
              # else
              #   puts "Checkbox Disabled"
              end
              
              break
            end
        end
      end

      @driver.manage.timeouts.implicit_wait = @implicitWait
      return blnUpdateSuccessful
    end
    # -----------------------------

  end
end